@@ -1,10 +1,8 @@
 import json
 
-from itertools import groupby
 from typing import Union
 
 from worker.data.api import API
-from worker.data import operations
 from worker.framework import constants
 from worker.framework.mixins import LoggingMixin, RedisMixin, RollbarMixin
 from worker.framework.state import State
