@@ -16,6 +16,17 @@ def gather_wits_for_period(asset_id, start, end, limit=1800):
     return wits_dataset
 
 
+def get_one_wits_record(asset_id, timestamp_sort=-1):
+    api_worker = API()
+    data = api_worker.get(path='/v1/data/corva/', collection='wits', asset_id=asset_id,
+                          sort="{timestamp:%s}" % timestamp_sort, limit=1).data
+    if not data:
+        return None
+
+    timestamp = data[0].get('timestamp', 0)
+    return timestamp
+
+
 def get_config_by_id(config_collection, _id):
     worker = API()
     config = worker.get(path="/v1/data/corva/%s/%s" % (config_collection, _id)).data
